==> haskell-pretty-simple-4.1.3.0-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pretty-simple
version:              4.1.3.0
visibility:           public
id:                   pretty-simple-4.1.3.0-C0xtydBbnCDBtuV6SU6ZwV
key:                  pretty-simple-4.1.3.0-C0xtydBbnCDBtuV6SU6ZwV
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  cf35af5198efa6cd002aa3f05ec73983
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.3.0-C0xtydBbnCDBtuV6SU6ZwV
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    prettyprinter-1.7.1-HnygYT0md3kGchHDXSnUtq
    prettyprinter-ansi-terminal-1.1.3-GLHJV3CRqnmGeQE2kGDKkf text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pretty-simple-4.1.3.0-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pretty-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pretty-simple
version:              4.1.3.0
visibility:           public
id:                   pretty-simple-4.1.3.0-8UXfH8YuAtTC8vxjfUlE1m
key:                  pretty-simple-4.1.3.0-8UXfH8YuAtTC8vxjfUlE1m
license:              BSD-3-Clause
copyright:            2017-2019 Dennis Gosnell
maintainer:           cdep.illabout@gmail.com
author:               Dennis Gosnell
homepage:             https://github.com/cdepillabout/pretty-simple
synopsis:             pretty printer for data types with a '\''Show'\'' instance.
description:
    Please see <https://github.com/cdepillabout/pretty-simple#readme README.md>.

category:             Text
abi:                  98e8b8b565b7373e7a0c2ae0bbb1b5c5
exposed:              True
exposed-modules:
    Debug.Pretty.Simple Text.Pretty.Simple Text.Pretty.Simple.Internal
    Text.Pretty.Simple.Internal.Color Text.Pretty.Simple.Internal.Expr
    Text.Pretty.Simple.Internal.ExprParser
    Text.Pretty.Simple.Internal.Printer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pretty-simple-4.1.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pretty-simple
hs-libraries:         HSpretty-simple-4.1.3.0-8UXfH8YuAtTC8vxjfUlE1m
depends:
    base-4.17.2.1 containers-0.6.7 mtl-2.2.2
    prettyprinter-1.7.1-IL3WuZoemUT4csWPo7vzAj
    prettyprinter-ansi-terminal-1.1.3-3Lf9YGV3v8x5Vfh24GASoE text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pretty-simple/html/pretty-simple.haddock

haddock-html:         /usr/share/doc/haskell-pretty-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
